@@ -30,10 +30,12 @@ proxy=None
 def init():
     global bus, proxy
 
-    bus=dbus.SessionBus()
+    if bus==None:
+	bus=dbus.SessionBus()
 
-    proxy=bus.get_object('com.nokia.HildonDesktop.AppMgr',
-	'/com/nokia/HildonDesktop/AppMgr')
+    if proxy==None:
+	proxy=bus.get_object('com.nokia.HildonDesktop.AppMgr',
+	    '/com/nokia/HildonDesktop/AppMgr')
 
 def launch(prog):
     global bus, proxy
