@@ -144,6 +144,12 @@ class FremantleRotation(object):
 
             self._mode = new_mode
 
+    def reset_mode(self):
+	if self._mode==self.AUTOMATIC:
+	    self._send_mce_request(self._ENABLE_ACCEL)
+	else:
+	    self._send_mce_request(self._DISABLE_ACCEL)
+
     def _send_mce_request(self, request):
         rpc = osso.Rpc(self._osso_context)
         rpc.rpc_run(self._MCE_SERVICE, \
